import {Injectable} from '@angular/core';
import {NGXLogger} from 'ngx-logger';
import {environment} from '@src/environments/environment';

@Injectable({
  providedIn: 'root'
})
export class LoggingService {
  env: string;
  canDebug: boolean;

  constructor(private logger: NGXLogger) {
    // TRACE|DEBUG|INFO|LOG|WARN|ERROR|FATAL|OFF
    this.env = environment.production ? 'Production' : 'Development';

    if (this.env === 'Development') {
      this.sendInfoLevelMessage('Dropping into debug mode');
    }
  }

  sendTraceLevelMessage(message, source, error): void {
    this.logger.trace(message, source, error);
  }

  sendDebugLevelMessage(message, source, error): void {
    this.logger.debug(message, source, error);
  }

  sendInfoLevelMessage(message): void {
    this.logger.info(message);
  }

  sendLogLevelMessage(message, source, error): void {
    this.logger.log(message, source, error);
  }

  sendWarnLevelMessage(message, error): void {
    this.logger.warn(message, error);
  }

  sendErrorLevelMessage(message, source, error): void {
    this.logger.error(message, source, error);
  }

  sendFatalLevelMessage(message, source, error): void {
    this.logger.fatal(message, source, error);
  }
}
